package com.ruoyi.weighbridge.service;

import java.util.List;
import com.ruoyi.weighbridge.domain.TblWeightinfo;

/**
 * 称重单Service接口
 * 
 * @author liuhj
 * @date 2022-03-10
 */
public interface ITblWeightinfoService 
{
    /**
     * 查询称重单
     * 
     * @param serialNo 称重单主键
     * @return 称重单
     */
    public TblWeightinfo selectTblWeightinfoBySerialNo(String serialNo);

    /**
     * 查询称重单列表
     * 
     * @param tblWeightinfo 称重单
     * @return 称重单集合
     */
    public List<TblWeightinfo> selectTblWeightinfoList(TblWeightinfo tblWeightinfo);

    /**
     * 新增称重单
     * 
     * @param tblWeightinfo 称重单
     * @return 结果
     */
    public int insertTblWeightinfo(TblWeightinfo tblWeightinfo);

    /**
     * 修改称重单
     * 
     * @param tblWeightinfo 称重单
     * @return 结果
     */
    public int updateTblWeightinfo(TblWeightinfo tblWeightinfo);

    /**
     * 批量删除称重单
     * 
     * @param serialNos 需要删除的称重单主键集合
     * @return 结果
     */
    public int deleteTblWeightinfoBySerialNos(String[] serialNos);

    /**
     * 删除称重单信息
     * 
     * @param serialNo 称重单主键
     * @return 结果
     */
    public int deleteTblWeightinfoBySerialNo(String serialNo);
}
